instrumenttools.transpose_notes_and_chords_in_expr_from_sounding_pitch_to_fingered_pitch
========================================================================================

.. autofunction:: abjad.tools.instrumenttools.transpose_notes_and_chords_in_expr_from_sounding_pitch_to_fingered_pitch.transpose_notes_and_chords_in_expr_from_sounding_pitch_to_fingered_pitch
